//保留两位小数
//功能：将浮点数四舍五入，取小数点后2位
function toDecimal(x) {
	if (x == "") {
		return 0;
	}
	var f = parseFloat(x);
	if (isNaN(f)) {
		return 0;
	}

	f = Math.round(x * 100) / 100;
	return f;
}
//功能：将输入值转换成INT
function toInt(x) {
	if (x == "") {
		return 0;
	}
	var f = parseInt(x);
	if (isNaN(f)) {
		return 0;
	}
	return f;
}

function myToFix(x) {
	if (x == "") {
		return 0;
	}
	var f = parseFloat(x);
	if (isNaN(f)) {
		return 0;
	}
	f = Math.round(x * 100) / 100;
	return f.toFixed(2);
}

/**
 * 数据类型验证，默认验证正浮点数
 * @param {} str 验证值
 * @param {} verificationType 验证类型 0：非负整数
 * @returns {} 是：true，否：false
 */
CheckNumberType = function(str, verificationType) {
	var type; //验证的正则表达式
	if (str == null || str == undefined) {
		return false;
	}
	switch (verificationType) {
		case 0:
			type = "^\\d+$"; //非负整数（正整数   +   0）
			break;
		case 1:
			type = "^[0-9]*[1-9][0-9]*$"; //正整数
			break;
		case 2:
			type = "^((-\\d+)|(0+))$"; //非正整数（负整数   +   0）
			break;
		case 3:
			type = "^-[0-9]*[1-9][0-9]*$"; //负整数    
			break;
		case 4:
			type = "^-?\\d+$"; //整数    
			break;
		case 5:
			type = "^\\d+(\\.\\d+)?$"; //非负浮点数（正浮点数   +   0）  
			break;
		case 6:
			type = "^(([0-9]+\\.[0-9]*[1-9][0-9]*)|([0-9]*[1-9][0-9]*\\.[0-9]+)|([0-9]*[1-9][0-9]*))$"; //正浮点数
			break;
		case 7:
			type = "^(-(([0-9]+\\.[0-9]*[1-9][0-9]*)|([0-9]*[1-9][0-9]*\\.[0-9]+)|([0-9]*[1-9][0-9]*)))$"; //负浮点数    
			break;
		case 8:
			type = "^(-?\\d+)(\\.\\d+)?$"; //浮点数   
			break;
		default:
			type = "^\\d+(\\.\\d+)?$"; //正浮点数
	}
	var re = new RegExp(type);
	if (str.match(re) == null) {
		return true;
	} else {
		return false;
	}
};

/**
 * 验证是否有效的手机号：是：true,否：false
 * @param {} str 手机号
 * @returns {} 
 */
IsMobile = function(str) {
	var re;
	if (!(/^1[3|4|5|6|7|8|9][0-9]\d{4,8}$/.test(str))) {
		re = false;
	} else if (str.length != 11) {
		re = false;
	} else {
		re = true;
	}
	return re;
};

IsCarNumber = function(str) {
	var re;
	if (!/^[A-Z0-9]{4,6}[黄蓝]{0,1}$|^[A-Z0-9]{4,5}[挂学警港澳]{1}$|^[A-Z0-9]{4}[应][急]$/.test(str)) {
		re = false;
	} else {
		re = true;
	}
	return re;
}
//字典类
function Dictionary() {
	var items = {}; //存储在一个Object的实例中  

	this.has = function(key) { //验证一个key是否是items对象的一个属性  
		return key in items;
	};
	this.set = function(key, value) { //设置属性  
		items[key] = value;
	};
	this.remove = function(key) { //移除key属性  
		if (this.has(key)) {
			delete items[key];
			return true;
		}
		return false;
	};
	this.get = function(key) { //查找特定属性  
		return this.has(key) ? items[key] : undefined;
	};
	this.values = function() { //返回所有value实例的值  
		var values = new Array(); //存到数组中返回  
		for (var k in items) {
			if (this.has(k)) {
				values.push(items[k]);
			}
		}
		return values;
	};
	this.getItems = function() { //获取  
		return items;
	};
	this.clear = function() { //清除  
		items = {};
	};
	this.size = function() { //获取属性的多少  
		return Object.keys(items).length;
	};
}
/**
 * 验证是否有效的VIN: null 表示验证通过，其他表示错误 
 * @param {} str 手机号
 * @returns {} 
 */
CheckVIN = function(vinNumber) {
	if (vinNumber == undefined || vinNumber == null || vinNumber.length != 17 || !(/^[A-Za-z0-9]{1,17}$/.test(vinNumber))) {
		return '请输入17位由字母和数字组成的VIN号码！';
	}

	if (vinNumber.indexOf('I') >= 0 || vinNumber.indexOf('O') >= 0 || vinNumber.indexOf('Q') >= 0) {
		return 'VIN中不会包含 I、O、Q 三个英文字母';
	}

    return null;
//  VIN校验规则存在缺陷，本地不做校验调用精友接口去校验
//	var vinMapWeighting = new Dictionary();
//	var vinMapValue = new Dictionary();
//	vinMapWeighting.set(1, 8);
//	vinMapWeighting.set(2, 7);
//	vinMapWeighting.set(3, 6);
//	vinMapWeighting.set(4, 5);
//	vinMapWeighting.set(5, 4);
//	vinMapWeighting.set(6, 3);
//	vinMapWeighting.set(7, 2);
//	vinMapWeighting.set(8, 10);
//	vinMapWeighting.set(9, 0);
//	vinMapWeighting.set(10, 9);
//	vinMapWeighting.set(11, 8);
//	vinMapWeighting.set(12, 7);
//	vinMapWeighting.set(13, 6);
//	vinMapWeighting.set(14, 5);
//	vinMapWeighting.set(15, 4);
//	vinMapWeighting.set(16, 3);
//	vinMapWeighting.set(17, 2);
//
//	vinMapValue.set('0', 0);
//	vinMapValue.set('1', 1);
//	vinMapValue.set('2', 2);
//	vinMapValue.set('3', 3);
//	vinMapValue.set('4', 4);
//	vinMapValue.set('5', 5);
//	vinMapValue.set('6', 6);
//	vinMapValue.set('7', 7);
//	vinMapValue.set('8', 8);
//	vinMapValue.set('9', 9);
//	vinMapValue.set('A', 1);
//	vinMapValue.set('B', 2);
//	vinMapValue.set('C', 3);
//	vinMapValue.set('D', 4);
//	vinMapValue.set('E', 5);
//	vinMapValue.set('F', 6);
//	vinMapValue.set('G', 7);
//	vinMapValue.set('H', 8);
//	vinMapValue.set('J', 1);
//	vinMapValue.set('K', 2);
//	vinMapValue.set('M', 4);
//	vinMapValue.set('L', 3);
//	vinMapValue.set('N', 5);
//	vinMapValue.set('P', 7);
//	vinMapValue.set('R', 9);
//	vinMapValue.set('S', 2);
//	vinMapValue.set('T', 3);
//	vinMapValue.set('U', 4);
//	vinMapValue.set('V', 5);
//	vinMapValue.set('W', 6);
//	vinMapValue.set('X', 7);
//	vinMapValue.set('Y', 8);
//	vinMapValue.set('Z', 9);
//
//	var amount = 0;
//	for (var i = 0; i < vinNumber.length; i++) {
//		//VIN码从从第一位开始，码数字的对应值×该位的加权值，计算全部17位的乘积值相加
//		amount += vinMapValue.get(vinNumber.substr(i, 1)) * vinMapWeighting.get(i + 1);
//	}
//
//	var remainder = amount % 11;
//	if (remainder == 10) {
//		if (vinNumber.substr(8, 1) != 'X') {
//			return 'VIN校验规则不通过,请核实VIN号码';
//		} else {
//			return null;
//		}
//	} else {
//		if (vinMapValue.get(vinNumber.substr(8, 1)) != remainder.toString()) {
//			return 'VIN校验规则不通过,请核实VIN号码';
//		} else {
//			return null;
//		}
//	}
};
//日期格式化
Date.prototype.format = function(fmt) {
	var o = {
		"M+": this.getMonth() + 1, //月份 
		"d+": this.getDate(), //日 
		"h+": this.getHours(), //小时 
		"m+": this.getMinutes(), //分 
		"s+": this.getSeconds(), //秒 
		"q+": Math.floor((this.getMonth() + 3) / 3), //季度 
		"S": this.getMilliseconds() //毫秒 
	};
	if (/(y+)/.test(fmt)) {
		fmt = fmt.replace(RegExp.$1, (this.getFullYear() + "").substr(4 - RegExp.$1.length));
	}
	for (var k in o) {
		if (new RegExp("(" + k + ")").test(fmt)) {
			fmt = fmt.replace(RegExp.$1, (RegExp.$1.length == 1) ? (o[k]) : (("00" + o[k]).substr(("" + o[k]).length)));
		}
	}
	return fmt;
};

Date.prototype.Format = function (fmt) {
    var o = {
        "M+": this.getMonth() + 1, //月份 
        "d+": this.getDate(), //日 
        "H+": this.getHours(), //小时 
        "m+": this.getMinutes(), //分 
        "s+": this.getSeconds(), //秒 
        "q+": Math.floor((this.getMonth() + 3) / 3), //季度 
        "S": this.getMilliseconds() //毫秒 
    };
    if (/(y+)/.test(fmt)) fmt = fmt.replace(RegExp.$1, (this.getFullYear() + "").substr(4 - RegExp.$1.length));
    for (var k in o)
    if (new RegExp("(" + k + ")").test(fmt)) fmt = fmt.replace(RegExp.$1, (RegExp.$1.length == 1) ? (o[k]) : (("00" + o[k]).substr(("" + o[k]).length)));
    return fmt;
}


//日期格式转换
function GetDateDiff(fmt, type) {
	switch (type) {
		case 1:
			//将xxxx/xx/xx的时间格式，转换为xxxx-xx-xx 的格式 
			return fmt.replace(/\//g, "-");
			break;
		default:
			//将xxxx-xx-xx的时间格式，转换为 xxxx/xx/xx的格式 
			return fmt.replace(/\-/g, "/");
			break;
	}
};
//隐藏手机号
function HideMObile(mobile) {
	var startValue = mobile.substring(0, 3);
	var endValue = mobile.substring(7, mobile.Length - 7);
	return startValue + "****" + endValue;
}
//功能：将输入值转换成字符串
function GetString(val, defaultVal) {
	if (!val) { //如果是NULL,undefined转换成空字符串
		return defaultVal == undefined ? "" : defaultVal;
	}
	return val;
}
//功能：是否是空字符串
function IsEmptyStr(val) {
	var rel = GetString(val);
	if (rel == "") {
		return true;
	}
	return false;
}
//去除字符串尾部空格或指定字符  
String.prototype.trimEnd = function(trimStr) {
	if (!trimStr) {
		return this;
	}
	var temp = this;
	while (true) {
		if (temp.substr(temp.length - trimStr.length, trimStr.length) != trimStr) {
			break;
		}
		temp = temp.substr(0, temp.length - trimStr.length);
	}
	return temp;
};
// 限制输入金额
function inputMoney(obj, event) {
	if ((event.keyCode >= 48 && event.keyCode <= 57) || event.keyCode == 46) {
		if (obj.value == '0' && (event.keyCode >= 48 && event.keyCode <= 57)) {
			obj.value = '';
			return true;
		} else {
			var index = obj.value.indexOf('.');
			if (index > -1) {
				if (event.keyCode == 46) {
					return false;
				} else {
					var iv = obj.value.substr(index + 1);
					if (iv.length >= 2) {
						return false;
					} else {
						return true;
					}
				}
			} else {
				return true;
			}
		}
	} else {
		return false;
	}
}
// 限制输入数字
function inputNumber(obj, event) {
	if ((event.keyCode >= 48 && event.keyCode <= 57)) {
		if (obj.value == '0' && (event.keyCode >= 48 && event.keyCode <= 57)) {
			obj.value = '';
			return true;
		} else {
			return true;
		}
	} else {
		return false;
	}
}
//验证是否为空
function isNullOrEmpty(e) {
	if (typeof(e) == 'object') {
		return "不允许为对象";
	}
	if (e == undefined) {
		return true;
	}
	e = e.replace(/\s/g, '')
	if (e == "" || e == null || e.length == 0) {
		return true;
	}
	return false;
}
//获得本地json数据，参数为回调函数
function GetLocalJson(url, fun) {
	$.ajax({
		type: "get",
		url: url,
		async: false,
		success: function(data) {
			var d1 = JSON.parse(data);
			fun(d1);
		}
	});
}
// 分割车牌号
function GetCarNumberInfo(carNumber) {
	var pref = carNumber.substr(0, 3).toString();

	var list = new Array(); // 特殊牌照列表
	list.push('国外');
	list.push('香港');
	list.push('澳门');
	list.push('台湾');
	list.push('WJ琼');
	list.push('WJ桂');
	list.push('WJ粤');
	list.push('WJ');
	list.push('ZK');
	list.push('KN');

	var isSpecial = false;
	var prefCarNumber = '';
	var lastCarNumber = '';
	$.each(list, function(index, value) {
		//console.log('index:'+index+' value:'+value);
		if (pref.indexOf(value) != -1) {
			prefCarNumber = value;
			lastCarNumber = carNumber.substr(value.length, (carNumber.length - value.length));
			isSpecial = true;
		}
	});
	if (!isSpecial) {
		prefCarNumber = carNumber.substr(0, 2);
		lastCarNumber = carNumber.substr(2, (carNumber.length - 2));
	}
	return {
		isSpecial: isSpecial,
		prefCarNumber: prefCarNumber,
		lastCarNumber: lastCarNumber
	};
}
// 选择器触发列样式移除mui-active
function liRemoveActive(obj) {
	$(obj).removeClass('mui-active');
	$(obj).parents('li').removeClass('mui-active');
}
//当前日期 YYYY-MM-DD
function GetNowFormatDate() {
    var date = new Date();                           
    var seperator1 = "-";
    var year = date.getFullYear();
    var month = date.getMonth() + 1;
    var strDate = date.getDate();
    if (month >= 1 && month <= 9) {
        month = "0" + month;
    }
    if (strDate >= 0 && strDate <= 9) {
        strDate = "0" + strDate;
    }
    var currentdate = year + seperator1 + month + seperator1 + strDate;
    return currentdate;
}

//时间选择器DtPicker
function InitDtPicker(dt,orderStartDate) {
	console.log(orderStartDate);
	var orderBeginDate = orderStartDate.split('-');
	console.log(orderBeginDate[0]);
		console.log(orderBeginDate[1]);
			console.log(orderBeginDate[2]);
	var date = new Date();
	var seperator1 = "-";
    var year = date.getFullYear();
    var month = date.getMonth();
    var strDate = date.getDate();
    if (month >= 1 && month <= 9) {
        month = "0" + month;
    }
    if (strDate >= 0 && strDate <= 9) {
        strDate = "0" + strDate;
    }
    var currentdate = year + seperator1 + month + seperator1 + strDate;
	document.activeElement.blur();
	//var thisID = this.getAttribute('id');
	var datePicker = new mui.DtPicker({
		type: 'date',
		beginYear: '1950',
		beginDate:new Date(orderBeginDate[0],orderBeginDate[1]-1,orderBeginDate[2]),
		endDate: new Date(year,month,strDate),
	});
	datePicker.show(function(items) {
		dt.value = items.y.value + '-' + items.m.value + '-' + items.d.value;
		datePicker.dispose();
	});
}